#
# spec file for package apache-commons-lang3
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define base_name lang3
%define short_name commons-%{base_name}
Name:           apache-commons-lang3
Version:        3.4
Release:        9.30
Summary:        Apache Commons Lang Package
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://commons.apache.org/%{base_name}
Source0:        http://archive.apache.org/dist/commons/lang/source/%{short_name}-%{version}-src.tar.gz
Patch0:         commons-lang3-3.4-javadoc.patch
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.6
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
BuildRequires:  junit
Provides:       %{short_name} = %{version}-%{release}
BuildArch:      noarch

%description
The standard Java libraries fail to provide enough methods for
manipulation of its core classes. The Commons Lang Component provides
these extra methods.

The Commons Lang Component provides a host of helper utilities for the
java.lang API, notably String manipulation methods, basic numerical
methods, object reflection, creation and serialization, and System
properties. Additionally it contains an inheritable enum type, an
exception structure that supports multiple types of nested-Exceptions
and a series of utilities dedicated to help with building methods, such
as hashCode, toString and equals.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{short_name}-%{version}-src
%patch0 -p1
sed -i 's/\r//' *.txt

%build
export OPT_JAR_LIST=`cat %{_sysconfdir}/ant.d/junit`
export CLASSPATH=
ant \
    -Dcompile.source=1.6 -Dcompile.target=1.6 \
    -Dfinal.name=%{short_name} \
     jar javadoc

%install
# jars
mkdir -p %{buildroot}%{_javadir}
cp -p target/%{short_name}.jar %{buildroot}%{_javadir}/%{name}.jar
(cd %{buildroot}%{_javadir} && for jar in apache-*; do ln -sf ${jar} `echo $jar| sed "s|apache-||g"`; done)

# pom
mkdir -p %{buildroot}%{_mavenpomdir}
cp -p pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap
# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr target/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}/%{name}/

%files
%doc LICENSE.txt NOTICE.txt RELEASE-NOTES.txt
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}.jar
%{_mavenpomdir}/*
%{_datadir}/maven-metadata/%{name}.xml

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Mon Oct  9 2017 fstrba@suse.com
- Modified patch:
  * commons-lang3-3.4-javadoc.patch
    + Fix build with jdk9
- Allow building with jdk9 too
- Run fdupes on javadoc
* Thu Sep 14 2017 fstrba@suse.com
- Specify java target and source level 1.6
- Force building with jdk < 1.9, since jdk9's javadoc chocks on one
  class file (internal error)
* Fri May 19 2017 pcervinka@suse.com
- New build dependency: javapackages-local
* Sun Jan 24 2016 p.drouand@gmail.com
- Initial release (version 3.4)
